@@ -4,7 +4,7 @@ package JSON::Schema::Modern::Document;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: One JSON Schema document
 
-our $VERSION = '0.553';
+our $VERSION = '0.554';
 
 use 5.020;
 use Moo;
@@ -21,7 +21,7 @@ use Ref::Util 0.100 'is_plain_hashref';
 use Safe::Isa 1.000008;
 use MooX::TypeTiny;
 use MooX::HandlesVia;
-use Types::Standard qw(InstanceOf HashRef Str Dict ArrayRef Enum ClassName Undef slurpy);
+use Types::Standard 1.016003 qw(InstanceOf HashRef Str Dict ArrayRef Enum ClassName Undef Slurpy);
 use namespace::clean;
 
 extends 'Mojo::JSON::Pointer';
@@ -62,7 +62,7 @@ has resource_index => (
       # the vocabularies used when evaluating instance data against schema
       vocabularies => ArrayRef[ClassName->where(q{$_->DOES('JSON::Schema::Modern::Vocabulary')})],
       configs => HashRef,
-      slurpy HashRef[Undef],  # no other fields allowed
+      Slurpy[HashRef[Undef]],  # no other fields allowed
     ]],
   handles_via => 'Hash',
   handles => {
@@ -216,7 +216,7 @@ JSON::Schema::Modern::Document - One JSON Schema document
 
 =head1 VERSION
 
-version 0.553
+version 0.554
 
 =head1 SYNOPSIS
 
